# GyphyFun

![](images/giphy.png)
Command line program that plays random giphy!

![](images/url.png)
You can copy the link by clicking on the window!

Created by vsDeus

## 1. Getting started
This script works by calling the [Giphy API](https://developers.giphy.com/docs/api).

You need to have python3 installed on your system.

## 2. Installation

### Installing using pip
Run ```pip3 install giphyfun --user```

### Installing from source
1. Clone this repository

```git clone https://github.com/vsDeus/giphyFun.git```

2. cd into the folder and install the package by executing

```cd cheermeup```

```pip3 install . --user```

from your terminal.

* Run the script by executing ```giphyfun``` and enjoy.